Crate humus_terra

Crate humus_terra 

humus-terra

humus-terra is an intuitive and robust framework for writing web-servers based on HTTP2.

Features

  • HTTP/2
  • Asynchronous Design

Modules

response
A module that provides abstraction and management of responses
route
A module that provides abstraction for routes and its helpers
terminal
A module that contains helper functions for terminal/command-line user interface such as logging system
tokens
A module that contains abstraction of stateless tokens

Macros

log
Log messages with specified severity levels.

Structs

App
An abstraction for hosting and routing.